# date

Le champ de saisie de date fixe reprend trois champs de saisie de texte.

## Dépendances
```shell
date
└─ core
```

## Utilisation
Afin d’utiliser le composant `date`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/blocs-fonctionnels/date-unique) sur le module Bloc fonctionnel de date unique